intervaltreetools.explode_intervals_into_n_trees_heuristically
==============================================================

.. autofunction:: abjad.tools.intervaltreetools.explode_intervals_into_n_trees_heuristically
